<?php
// settings page and AJAX sorting
add_action('admin_menu' , 'faq_enable_pages'); 

function faq_enable_pages() {
    add_submenu_page('edit.php?post_type=question', 'Sort FAQs', 'Sort FAQs', 'edit_posts', basename(__FILE__), 'faq_sort_questions');
	add_submenu_page('edit.php?post_type=question', 'Settings', 'Settings', 'manage_options', 'faq-options', 'faq_settings_page');
}


function faq_sort_questions() {
	$questions = new WP_Query('post_type=question&posts_per_page=-1&orderby=menu_order&order=ASC');
?>
	<div class="wrap">
	<h3>Sort FAQs <img src="<?php bloginfo('url'); ?>/wp-admin/images/loading.gif" id="loading-animation" /></h3>
    <p><strong>Note:</strong> this only affects the FAQs listed using the shortcode functions</p>
	<ul id="custom-type-list">
	<?php while ( $questions->have_posts() ) : $questions->the_post(); ?>
		<li id="<?php the_id(); ?>"><?php the_title(); ?></li>			
	<?php endwhile; ?>
    </ul>
	</div>

<?php }

function faq_questions_print_styles() {
	global $pagenow;
 
	$pages = array('edit.php');
	if (in_array($pagenow, $pages))
		wp_enqueue_style('faq_questions_style', plugins_url( 'css/sortable.css', __FILE__ ), array(), '1.01', 'screen' );
}
add_action( 'admin_print_styles', 'faq_questions_print_styles' );

function faq_questions_print_scripts() {
	global $pagenow;
 
	$pages = array('edit.php');
	if (in_array($pagenow, $pages)) {
		wp_enqueue_script('jquery-ui-sortable');
        wp_enqueue_script('faq_questions_script', plugins_url( 'js/custom-type-sort.js', __FILE__ ));
	}
}
add_action( 'admin_print_scripts', 'faq_questions_print_scripts' );


function save_faq_questions_order() {
	global $wpdb; // WordPress database class
 
	$order = explode(',', $_POST['order']);
	$counter = 0;
 
	foreach ($order as $question_id) {
		$wpdb->update($wpdb->posts, array( 'menu_order' => $counter ), array( 'ID' => $question_id) );
		$counter++;
	}
	die(1);
}
add_action('wp_ajax_faq_questions_sort', 'save_faq_questions_order');

	//call register settings function
add_action( 'admin_init', 'register_faq_settings' );


function register_faq_settings() {
	//register our settings
	register_setting( 'faq-options-group', 'faq_css' );
	register_setting( 'faq-options-group', 'faq_rss' );	
	register_setting( 'faq-options-group', 'faq_widget' );		
//	register_setting( 'faq-options-group', 'faq_loop' );		
}

function faq_settings_page() {

    //must check that the user has the required capability 
    if (!current_user_can('manage_options'))
    {
      wp_die( __('You do not have sufficient permissions to access this page.') );
    }
	?>
<div class="wrap">
    <h2>FAQ Manager Settings</h2>
	<p>Options relating to the FAQ manager</p>
<hr />
<form method="post" action="options.php">
    <?php settings_fields( 'faq-options-group' ); ?>
    
<p>	<?php if(get_option('faq_css')){ $checked = 'checked="checked"'; }else{ $checked = "";} ?>
    <input type="checkbox" name="faq_css" id="faq_css" value="true" <?php echo $checked; ?> />
    <label for="faq_css">Load default CSS</label>
</p>
<p>
	<?php if(get_option('faq_rss')){ $checked = 'checked="checked"'; }else{ $checked = "";} ?>
    <input type="checkbox" name="faq_rss" id="faq_rss" value="true" <?php echo $checked; ?> />
    <label for="faq_rss">Include in RSS feed</label>
</p>
<p>
	<?php if(get_option('faq_widget')){ $checked = 'checked="checked"'; }else{ $checked = "";} ?>
    <input type="checkbox" name="faq_widget" id="faq_widget" value="true" <?php echo $checked; ?> />
    <label for="faq_widget">Load "Random FAQ" widget</label>
</p>
<!-- <p>
	<?php //if(get_option('faq_loop')){ $checked = 'checked="checked"'; }else{ $checked = "";} ?>
    <input type="checkbox" name="faq_loop" id="faq_loop" value="true" <?php echo $checked; ?> />
    <label for="faq_loop">Include FAQs in home page loop</label>
</p>
-->

    <p class="submit">
    <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
    </p>

</form>
</div>

<?php }


// adds default CSS to theme

function faq_css() {
// Optional setting for loading CSS
		if(get_option('faq_css') == 'true') {
        $faqmanagerUrl = WP_PLUGIN_URL . '/faq-manager/inc/css/faq-default.css';
        $faqmanagerFile = WP_PLUGIN_DIR . '/faq-manager/inc/css/faq-default.css';
        if ( file_exists($faqmanagerFile) ) {
            wp_register_style('faqmanagerSheet', $faqmanagerUrl);
            wp_enqueue_style( 'faqmanagerSheet');
        }
    }
}
add_action( 'wp_print_styles', 'faq_css' );

// This will add *all* custom post types to the RSS feed naturally
function faq_include_rss( $query ) {
	if(get_option('faq_rss') == 'true') {
	if ($query->is_feed) {
		$args = array(
				'public' => true,
				'_builtin' => false
				);
		$output = 'names';
		$operator = 'and';
		$post_types = get_post_types( $args , $output , $operator );
		// remove 'pages' from the RSS
		$post_types = array_merge( $post_types, array('post') ) ;
		$query->set( 'post_type' , $post_types );
		}
	}
	return $query;
}
add_filter( 'pre_get_posts' , 'faq_include_rss' );

//display contextual help for FAQs (will be filled in)
add_action( 'contextual_help', 'add_faqhelp_text', 10, 3 );

function add_faqhelp_text($contextual_help, $screen_id, $screen) { 
  //$contextual_help .= var_dump($screen); // use this to help determine $screen->id
  if ('question' == $screen->id ) {
    $contextual_help =
      '<p>' . __('Things to remember when adding or editing an FAQ:') . '</p>' .
      '<ul>' .
      '<li>' . __('Include both the question and the answer.') . '</li>' .
      '<li>' . __('Use the included taxonomies (FAQ topics and tags) to organize your FAQs and display in your menu.') . '</li>' .
      '</ul>' .
      '<p><strong>' . __('For more information:') . '</strong></p>' .
      '<p>' . __('<a href="http://codex.wordpress.org/Posts_Edit_SubPanel" target="_blank">Edit Posts Documentation</a>') . '</p>' .
      '<p>' . __('<a href="http://wordpress.org/support/" target="_blank">Support Forums</a>') . '</p>' ;
  } elseif ( 'edit-question' == $screen->id ) {
    $contextual_help = 
      '<p>' . __('Things to remember when adding or editing an FAQ:') . '</p>' .
      '<ul>' .
      '<li>' . __('Include both the question and the answer.') . '</li>' .
      '<li>' . __('Use the included taxonomies (FAQ topics and tags) to organize your FAQs and display in your menu.') . '</li>' .
      '</ul>' ;
  }
  return $contextual_help;
}

//add shortened excerpt for widget

function faq_widget_excerpt($limit) {
      $excerpt = explode(' ', get_the_excerpt(), $limit);
      if (count($excerpt)>=$limit) {
        array_pop($excerpt);
        $excerpt = implode(" ",$excerpt).'...';
      } else {
        $excerpt = implode(" ",$excerpt);
      } 
      $excerpt = preg_replace('`\[[^\]]*\]`','',$excerpt);
      return $excerpt;
    }